## Genkit - Sample Agents

* [**Movie Info Agent**](/samples/js/src/agents/movie-agent/README.md) 
This agent uses the TMDB API to answer questions about movies

* [**Coder Agent**](/samples/js/src/agents/coder/README.md)  
This is a simple code-writing agent that emits full code files as artifacts.
